TransformMut

Struct TransformMut 

pub struct TransformMut {
    steps: Box<[AnyStepMut]>,
    stat_processed: AtomicU32,
    stat_dropped: AtomicU32,
}
Mutable measurement transformation.

Unlike Transform, this transformation may contain steps using mutable state. Since the mutable state is typically modified based on the input measurement, the order of transform calls is significant. Transform guarantees that calls to its transform method will always return the same result for the same input. This does not hold for TransformMut, which may return different results depending on the internal state.

A TransformMut is created using its FromIterator implementation (e.g. calling collect on an iterator of AnyStepMuts).

Fields

steps: Box<[AnyStepMut]>stat_processed: AtomicU32stat_dropped: AtomicU32

Implementations



impl TransformMut

const fn new(steps: Box<[AnyStepMut]>) -> Self

pub fn stat(&self) -> Stat

Returns the statistics of this transform.

pub fn transform(&mut self, measurement: Measurement) -> Option<Measurement>

Transforms a measurement.

Returns None if the measurement was dropped.

fn transform_impl( &mut self, timestamp: DateTime<Utc>, attributes: &Attributes, value: &mut Value, ) -> Outcome